#!/bin/bash
set -e

#Written by Brian Bushnell
#Last updated July 31, 2019

#Filters prokaryotic clades, translates them to protein, and sketches them.
#To use this script outside of NERSC, modify $TAXPATH to point to your directory with the BBTools taxonomy data,
#e.g. TAXPATH="/path/to/taxonomy_directory/"

TAXPATH="auto"

#Ensure necessary executables are in your path
module load pigz

mkdir prot
time filterbytaxa.sh in=sorted.fa.gz out=prot/prok.fa.gz fastawrap=1023 ids=10239,12884,2,2157 tree=auto -Xmx16g include taxpath=$TAXPATH bgzip pigz unpigz
cd prot
#TODO: Ordered does not work; it hangs.
time callgenes.sh in=prok.fa.gz outa=prot.faa.gz -Xmx16g ow ordered=f zl=9 bgzip pigz unpigz

wget -q -O - ftp://ftp.ncbi.nlm.nih.gov/refseq/release/protozoa/*genomic.fna.gz | gi2taxid.sh -Xmx1g in=stdin.fa.gz out=protozoa.fa.gz pigz=32 bgzip unpigz zl=9 server ow
wget -q -O - ftp://ftp.ncbi.nlm.nih.gov/refseq/release/mitochondrion/*genomic.fna.gz | gi2taxid.sh -Xmx1g in=stdin.fa.gz out=mito.fa.gz pigz=32 bgzip unpigz zl=9 server ow
wget -q -O - ftp://ftp.ncbi.nlm.nih.gov/refseq/release/plastid/*genomic.fna.gz | gi2taxid.sh -Xmx1g in=stdin.fa.gz out=chloro.fa.gz pigz=32 bgzip unpigz zl=9 server ow

time callgenes.sh in=prok.fa.gz outa=prok.faa.gz -Xmx16g ow ordered=f zl=9 bgzip pigz unpigz
time callgenes.sh in=protozoa.fa.gz outa=protozoa.faa.gz -Xmx16g ow ordered=f zl=9 bgzip pigz unpigz
time callgenes.sh in=mito.fa.gz outa=mito.faa.gz -Xmx16g ow ordered=f zl=9 bgzip pigz unpigz
time callgenes.sh in=chloro.fa.gz outa=chloro.faa.gz -Xmx16g ow ordered=f zl=9 bgzip pigz unpigz

cat prok.faa.gz mito.faa.gz chloro.faa.gz protozoa.faa.gz > all.faa.gz

time sketchblacklist.sh -Xmx63g in=prot.faa.gz prepasses=1 tree=auto taxa taxlevel=family ow out=blacklist_prokprot_family_40.sketch mincount=40 k=9,12 sizemult=2 amino
time sketchblacklist.sh -Xmx63g in=prot.faa.gz prepasses=1 tree=auto taxa taxlevel=genus ow out=blacklist_prokprot_genus_80.sketch mincount=80 k=9,12 sizemult=2 amino
mergesketch.sh -Xmx1g in=blacklist_prokprot_genus_80.sketch,blacklist_prokprot_family_40.sketch out=blacklist_prokprot_merged.sketch amino name0=blacklist_prokprot_merged k=9,12 ow
time bbsketch.sh -Xmx63g in=all.faa.gz out=taxa#.sketch mode=taxa tree=auto files=31 ow unpigz minsize=200 prefilter autosize blacklist=blacklist_prokprot_merged.sketch k=9,12 depth sizemult=2 amino
